/*

Copyright (c) 2001-2003 Michael Terry

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#ifndef _FIO_H_
#define _FIO_H_

#include <gtk/gtk.h>

gchar *fio_get_file (const gchar *name);
gboolean fio_set_file (const gchar *name, const gchar *value);
void fio_remove_file (const gchar *filename);

gint fio_get_values_from_file (const gchar *filename, ...);
gint fio_set_values_to_file (const gchar *filename, ...);

gchar *str_replace_tokens (gchar **string, gchar obj, gchar *replacement);

gchar *fio_unique_name (const gchar *prefix);

#endif /* _FIO_H_ */










